| Title: | Estimation and Inference of Two-Way pAUC, pAUC and pODC |
|---|---|
| Description: | Tools for estimating and inferring two-way partial area under receiver operating characteristic curves (two-way pAUC), partial area under receiver operating characteristic curves (pAUC), and partial area under ordinal dominance curves (pODC). Methods includes Mann-Whitney statistic and Jackknife, etc. |
| Authors: | Hanfang Yang, Kun Lu, Xiang Lyu, Feifang Hu, Yichuan Zhao |
| Maintainer: | Xiang Lyu <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 2.1.1 |
| Built: | 2026-05-11 06:11:29 UTC |
| Source: | https://github.com/cran/tpAUC |
Estimate and infer the area of region under ODC curve with pre-specific FNR constraint (FNR-pODC). See Yang et al., 2017 for details.
podc(response, predictor, threshold = 0.9, method = "MW", ci = TRUE, cp = 0.95, smooth = FALSE)podc(response, predictor, threshold = 0.9, method = "MW", ci = TRUE, cp = 0.95, smooth = FALSE)
response |
a factor, numeric or character vector of responses; typically encoded with 0 (negative) and 1 (positive). Only two classes can be used in a ROC curve. If its levels are not 0/1, the first level will be defaultly regarded as negative. |
predictor |
a numeric vector of the same length than response, containing the predicted value of each observation. An ordered factor is coerced to a numeric. |
threshold |
numeric; false negative rate (FNR) constraint. |
method |
methods to estimate FNR-pODC. |
ci |
logic; compute the confidence interval of estimation? |
cp |
numeric; coverage probability of confidence interval. |
smooth |
if |
This function estimates and infers FNR partial ODC given response, predictor and pre-specific FNR constraint.
MW: Mann-Whitney statistic. expect: method in Yang et al., 2017 adapted from Wang and Chang, 2011. jackknife: jackknife method in Yang et al., 2017.
Estimation and Inference of FNR partial ODC.
Hanfang Yang, Kun Lu, Xiang Lyu, Feifang Hu, Yichuan Zhao.
library('pROC') data(aSAH) podc(aSAH$outcome, aSAH$s100b,threshold=0.9, method='expect',ci=TRUE, cp=0.95 )library('pROC') data(aSAH) podc(aSAH$outcome, aSAH$s100b,threshold=0.9, method='expect',ci=TRUE, cp=0.95 )
Infer the area of region under ordinal dominance curve with pre-specific FNR constraint (FNR-pODC). See Yang et al., 2017 for details.
podc.ci(response, predictor, cp = 0.95, threshold = 0.9, method = "MW")podc.ci(response, predictor, cp = 0.95, threshold = 0.9, method = "MW")
response |
a factor, numeric or character vector of responses; typically encoded with 0 (negative) and 1 (positive). Only two classes can be used in a ROC curve. If its levels are not 0 and 1, the first level will be defaultly regarded as negative. |
predictor |
a numeric vector of the same length than response, containing the predicted value of each observation. An ordered factor is coerced to a numeric. |
cp |
numeric; coverage probability of confidence interval. |
threshold |
numeric; false negative rate (FNR) constraint. |
method |
methods to estimate partial ODC. |
This function infers FNR partial ODC given response, predictor and pre-specific FNR constraint.
MW: Mann-Whitney statistic. expect: method in (2.2) Wang and Chang, 2011. jackknife: jackknife method in Yang et al., 2017.
Confidence interval of FNR partial ODC.
Hanfang Yang, Kun Lu, Xiang Lyu, Feifang Hu, Yichuan Zhao.
library('pROC') data(aSAH) podc.ci(aSAH$outcome, aSAH$s100b, method='expect',threshold=0.8, cp=0.97)library('pROC') data(aSAH) podc.ci(aSAH$outcome, aSAH$s100b, method='expect',threshold=0.8, cp=0.97)
Estimate the area of region under ordinal dominance curve with pre-specific FNR constraint (FNR-pODC). See Yang et al., 2017 for details.
podc.est(response, predictor, threshold = 0.9, method = "MW", smooth = FALSE)podc.est(response, predictor, threshold = 0.9, method = "MW", smooth = FALSE)
response |
a factor, numeric or character vector of responses; typically encoded with 0 (negative) and 1 (positive). Only two classes can be used in a ROC curve. If its levels are not 0 and 1, the first level will be defaultly regarded as negative. |
predictor |
a numeric vector of the same length than response, containing the predicted value of each observation. An ordered factor is coerced to a numeric. |
threshold |
numeric; false negative rate (FNR) constraint. |
method |
methods to estimate partial ODC. |
smooth |
if |
This function estimates FNR partial ODC given response, predictor and pre-specific FNR constraint.
MW: Mann-Whitney statistic. expect: method in Yang et al., 2017 adapted from Wang and Chang, 2011. jackknife: jackknife method in Yang et al., 2017.
Estimation of FNR partial ODC.
Hanfang Yang, Kun Lu, Xiang Lyu, Feifang Hu, Yichuan Zhao.
library('pROC') data(aSAH) podc.est(aSAH$outcome, aSAH$s100b, method='expect',threshold=0.8 )library('pROC') data(aSAH) podc.est(aSAH$outcome, aSAH$s100b, method='expect',threshold=0.8 )
Estimate and infer the area of region under ROC curve with pre-specific FPR constraint (FPR-pAUC). See Yang et al., 2017 for details.
proc(response, predictor, threshold = 0.9, method = "MW", ci = TRUE, cp = 0.95, smooth = FALSE)proc(response, predictor, threshold = 0.9, method = "MW", ci = TRUE, cp = 0.95, smooth = FALSE)
response |
a factor, numeric or character vector of responses; typically encoded with 0 (negative) and 1 (positive). Only two classes can be used in a ROC curve. If its levels are not 0/1, the first level will be defaultly regarded as negative. |
predictor |
a numeric vector of the same length than response, containing the predicted value of each observation. An ordered factor is coerced to a numeric. |
threshold |
numeric; false positive rate (FPR) constraint. |
method |
methods to estimate FPR-pAUC. |
ci |
logic; compute the confidence interval of estimation? |
cp |
numeric; coverage probability of confidence interval. |
smooth |
if |
This function estimates and infers FPR partial AUC given response, predictor and pre-specific FPR constraint.
MW: Mann-Whitney statistic. expect: method in (2.2) Wang and Chang, 2011. jackknife: jackknife method in Yang et al., 2017.
Estimate and Inference of FPR partial AUC.
Hanfang Yang, Kun Lu, Xiang Lyu, Feifang Hu, Yichuan Zhao.
roc, tproc.est, proc.est, proc.ci
library('pROC') data(aSAH) proc(aSAH$outcome, aSAH$s100b,threshold=0.9, method='expect',ci=TRUE, cp=0.95)library('pROC') data(aSAH) proc(aSAH$outcome, aSAH$s100b,threshold=0.9, method='expect',ci=TRUE, cp=0.95)
Infer the area of region under ROC curve with pre-specific FPR constraint (FPR-pAUC). See Yang et al., 2017 for details.
proc.ci(response, predictor, cp = 0.95, threshold = 0.9, method = "MW")proc.ci(response, predictor, cp = 0.95, threshold = 0.9, method = "MW")
response |
a factor, numeric or character vector of responses; typically encoded with 0 (negative) and 1 (positive). Only two classes can be used in a ROC curve. If its levels are not 0/1, the first level will be defaultly regarded as negative. |
predictor |
a numeric vector of the same length than response, containing the predicted value of each observation. An ordered factor is coerced to a numeric. |
cp |
numeric; coverage probability of confidence interval. |
threshold |
numeric; false positive rate (FPR) constraint. |
method |
methods to estimate FPR-pAUC. |
This function infers FPR partial AUC given response, predictor and pre-specific FPR constraint.
MW: Mann-Whitney statistic. method in Yang et al., 2017 adapted from Wang and Chang, 2011. jackknife: jackknife method in Yang et al., 2017.
Confidence interval of FPR partial AUC.
Hanfang Yang, Kun Lu, Xiang Lyu, Feifang Hu, Yichuan Zhao.
library('pROC') data(aSAH) proc.ci(aSAH$outcome, aSAH$s100b, cp=0.95 ,threshold=0.9,method='expect')library('pROC') data(aSAH) proc.ci(aSAH$outcome, aSAH$s100b, cp=0.95 ,threshold=0.9,method='expect')
Estimate the area of region under ROC curve with pre-specific FPR constraint (FPR-pAUC). See Yang et al., 2017 for details.
proc.est(response, predictor, threshold = 0.9, method = "MW", smooth = FALSE)proc.est(response, predictor, threshold = 0.9, method = "MW", smooth = FALSE)
response |
a factor, numeric or character vector of responses; typically encoded with 0 (negative) and 1 (positive). Only two classes can be used in a ROC curve. If its levels are not 0 and 1, the first level will be defaultly regarded as negative. |
predictor |
a numeric vector of the same length than response, containing the predicted value of each observation. An ordered factor is coerced to a numeric. |
threshold |
numeric; false positive rate (FPR) constraint. |
method |
methods to estimate FPR-pAUC. |
smooth |
if |
This function estimates FPR partial AUC given response, predictor and pre-specific FPR constraint.
MW: Mann-Whitney statistic. expect: method in (2.2) Wang and Chang, 2011. jackknife: jackknife method in Yang et al., 2017.
Estimate of FPR partial AUC.
Hanfang Yang, Kun Lu, Xiang Lyu, Feifang Hu, Yichuan Zhao.
library('pROC') data(aSAH) proc.est(aSAH$outcome, aSAH$s100b, method='expect',threshold=0.8)library('pROC') data(aSAH) proc.est(aSAH$outcome, aSAH$s100b, method='expect',threshold=0.8)
Tools of estimation and inference of two-way partial AUC, FPR partial AUC and FNR partial ODC. Methods are proposed in Yang et al., 2016 and Yang et al., 2017, including Mann-Whitney Statistic, jackknife method, etc.
| Package: | tpAUC |
| Type: | Package |
| Date | 2017-04-08 |
| License: | GPL (>= 2) |
| Hanfang Yang, Kun Lu, Xiang Lyu, Feifang Hu, Yichuan Zhao. |
| Maintainer: Xiang Lyu <[email protected]> |
| Wang Z, Chang Y. Marker selection via maximizing the partial area under the ROC curve of linear risk scores[J]. Biostatistics, 2011, 12(2): 369-385. |
| Yang H, Lu K, Lyu X, Hu F. Two-Way Partial AUC and Its Properties[J]. arXiv:1508.00298, 2016. |
| Yang H, Lu K, Zhao Y. A nonparametric approach for partial areas under ROC curves and ordinal dominance curves. Statistica Sinica, 2017, 27: 357-371. |
Estimate the area of region under ROC curve under pre-specific FPR/TPR constraints (two-way partial AUC). See Yang et al., 2016 for details.
tproc.est(response, predictor, threshold = c(1, 0), smooth = FALSE)tproc.est(response, predictor, threshold = c(1, 0), smooth = FALSE)
response |
a factor, numeric or character vector of responses; typically encoded with 0 (negative) and 1 (positive). Only two classes can be used in a ROC curve. If its levels are not 0 and 1, the first level will be defaultly regarded as negative. |
predictor |
a numeric vector of the same length than response, containing the predicted value of each observation. An ordered factor is coerced to a numeric. |
threshold |
a length-two numeric vector; the first element is FPR threshold, the second is TPR. |
smooth |
if |
This function estimates two-way partial AUC given response, predictor and pre-specific FPR/TPR constraints.
Estimate of two-way partial AUC.
Hanfang Yang, Kun Lu, Xiang Lyu, Feifang Hu, Yichuan Zhao.
library('pROC') data(aSAH) tproc.est(aSAH$outcome, aSAH$s100b, threshold=c(0.8,0.2))library('pROC') data(aSAH) tproc.est(aSAH$outcome, aSAH$s100b, threshold=c(0.8,0.2))